==> zio-aws-kinesisanalyticsv2_3-5.17.153.1-sources.jar: zio/aws/kinesisanalyticsv2/model/SourceSchema.scala <==
package zio.aws.kinesisanalyticsv2.model
import zio.ZIO
import zio.aws.kinesisanalyticsv2.model.primitives.RecordEncoding
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class SourceSchema(
    recordFormat: zio.aws.kinesisanalyticsv2.model.RecordFormat,
    recordEncoding: Option[RecordEncoding] = None,
    recordColumns: Iterable[zio.aws.kinesisanalyticsv2.model.RecordColumn]
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kinesisanalyticsv2.model.SourceSchema = {
    import SourceSchema.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kinesisanalyticsv2.model.SourceSchema
      .builder()
      .recordFormat(recordFormat.buildAwsValue())
      .optionallyWith(
        recordEncoding.map(value =>
          RecordEncoding.unwrap(value): java.lang.String
        )
      )(_.recordEncoding)
      .recordColumns(recordColumns.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .build()
  }
  def asReadOnly: zio.aws.kinesisanalyticsv2.model.SourceSchema.ReadOnly =
    zio.aws.kinesisanalyticsv2.model.SourceSchema.wrap(buildAwsValue())
}
object SourceSchema {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kinesisanalyticsv2.model.SourceSchema
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kinesisanalyticsv2.model.SourceSchema =
      zio.aws.kinesisanalyticsv2.model.SourceSchema(
        recordFormat.asEditable,
        recordEncoding.map(value => value),
        recordColumns.map { item =>
          item.asEditable
        }
      )
    def recordFormat: zio.aws.kinesisanalyticsv2.model.RecordFormat.ReadOnly
    def recordEncoding: Option[RecordEncoding]
    def recordColumns
        : List[zio.aws.kinesisanalyticsv2.model.RecordColumn.ReadOnly]
    def getRecordFormat: ZIO[
      Any,
      Nothing,
      zio.aws.kinesisanalyticsv2.model.RecordFormat.ReadOnly
    ] = ZIO.succeed(recordFormat)
    def getRecordEncoding: ZIO[Any, AwsError, RecordEncoding] =
      AwsError.unwrapOptionField("recordEncoding", recordEncoding)
    def getRecordColumns: ZIO[Any, Nothing, List[
      zio.aws.kinesisanalyticsv2.model.RecordColumn.ReadOnly
    ]] = ZIO.succeed(recordColumns)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kinesisanalyticsv2.model.SourceSchema
  ) extends zio.aws.kinesisanalyticsv2.model.SourceSchema.ReadOnly {
    override val recordFormat
        : zio.aws.kinesisanalyticsv2.model.RecordFormat.ReadOnly =
      zio.aws.kinesisanalyticsv2.model.RecordFormat.wrap(impl.recordFormat())
    override val recordEncoding: Option[RecordEncoding] = scala
      .Option(impl.recordEncoding())
      .map(value =>
        zio.aws.kinesisanalyticsv2.model.primitives.RecordEncoding(value)
      )
    override val recordColumns
        : List[zio.aws.kinesisanalyticsv2.model.RecordColumn.ReadOnly] = impl
      .recordColumns()
      .asScala
      .map { item =>
        zio.aws.kinesisanalyticsv2.model.RecordColumn.wrap(item)
      }
      .toList
  }
  def wrap(
      impl: software.amazon.awssdk.services.kinesisanalyticsv2.model.SourceSchema
  ): zio.aws.kinesisanalyticsv2.model.SourceSchema.ReadOnly = new Wrapper(impl)
}

==> zio-aws-kinesisanalyticsv2_3-6.20.42.1-sources.jar: zio/aws/kinesisanalyticsv2/model/SourceSchema.scala <==
package zio.aws.kinesisanalyticsv2.model
import zio.ZIO
import zio.aws.kinesisanalyticsv2.model.primitives.RecordEncoding
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class SourceSchema(
    recordFormat: zio.aws.kinesisanalyticsv2.model.RecordFormat,
    recordEncoding: Optional[RecordEncoding] = Optional.Absent,
    recordColumns: Iterable[zio.aws.kinesisanalyticsv2.model.RecordColumn]
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kinesisanalyticsv2.model.SourceSchema = {
    import SourceSchema.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kinesisanalyticsv2.model.SourceSchema
      .builder()
      .recordFormat(recordFormat.buildAwsValue())
      .optionallyWith(
        recordEncoding.map(value =>
          RecordEncoding.unwrap(value): java.lang.String
        )
      )(_.recordEncoding)
      .recordColumns(recordColumns.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .build()
  }
  def asReadOnly: zio.aws.kinesisanalyticsv2.model.SourceSchema.ReadOnly =
    zio.aws.kinesisanalyticsv2.model.SourceSchema.wrap(buildAwsValue())
}
object SourceSchema {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kinesisanalyticsv2.model.SourceSchema
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kinesisanalyticsv2.model.SourceSchema =
      zio.aws.kinesisanalyticsv2.model.SourceSchema(
        recordFormat.asEditable,
        recordEncoding.map(value => value),
        recordColumns.map { item =>
          item.asEditable
        }
      )
    def recordFormat: zio.aws.kinesisanalyticsv2.model.RecordFormat.ReadOnly
    def recordEncoding: Optional[RecordEncoding]
    def recordColumns
        : List[zio.aws.kinesisanalyticsv2.model.RecordColumn.ReadOnly]
    def getRecordFormat: ZIO[
      Any,
      Nothing,
      zio.aws.kinesisanalyticsv2.model.RecordFormat.ReadOnly
    ] = ZIO.succeed(recordFormat)
    def getRecordEncoding: ZIO[Any, AwsError, RecordEncoding] =
      AwsError.unwrapOptionField("recordEncoding", recordEncoding)
    def getRecordColumns: ZIO[Any, Nothing, List[
      zio.aws.kinesisanalyticsv2.model.RecordColumn.ReadOnly
    ]] = ZIO.succeed(recordColumns)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kinesisanalyticsv2.model.SourceSchema
  ) extends zio.aws.kinesisanalyticsv2.model.SourceSchema.ReadOnly {
    override val recordFormat
        : zio.aws.kinesisanalyticsv2.model.RecordFormat.ReadOnly =
      zio.aws.kinesisanalyticsv2.model.RecordFormat.wrap(impl.recordFormat())
    override val recordEncoding: Optional[RecordEncoding] =
      zio.aws.core.internal
        .optionalFromNullable(impl.recordEncoding())
        .map(value =>
          zio.aws.kinesisanalyticsv2.model.primitives.RecordEncoding(value)
        )
    override val recordColumns
        : List[zio.aws.kinesisanalyticsv2.model.RecordColumn.ReadOnly] = impl
      .recordColumns()
      .asScala
      .map { item =>
        zio.aws.kinesisanalyticsv2.model.RecordColumn.wrap(item)
      }
      .toList
  }
  def wrap(
      impl: software.amazon.awssdk.services.kinesisanalyticsv2.model.SourceSchema
  ): zio.aws.kinesisanalyticsv2.model.SourceSchema.ReadOnly = new Wrapper(impl)
}
